import { logger } from '../../core/logger.js';
import { Command } from '../utils/cli-handler.js';
import { exec, cmd } from '../utils/utils.js';
import { getPackageExecutor } from '../utils/runtime-utils.js';

const command = new Command("upgrade").description("Upgrades your Robo to the latest version").option("-f", "--force", "forcefully install").option("-ns", "--no-self-check", "do not check for updates to Sage CLI").option("-s", "--silent", "do not print anything").option("-v", "--verbose", "print more information for debugging").handler(upgradeAction);
var upgrade_default = command;
async function upgradeAction(_files, options) {
  logger({
    enabled: !options.silent,
    level: options.verbose ? "debug" : "info"
  }).info(`Forwarding to Sage CLI...`);
  const packageExecutor = getPackageExecutor();
  const args = process.argv.slice(3);
  logger.debug(`Package executor:`, packageExecutor);
  logger.debug(`Arguments:`, args);
  await exec(`${cmd(packageExecutor)} @roboplay/sage upgrade ${args.join(" ")}`);
}

export { upgrade_default as default, upgradeAction };
