import { Config } from '../types/index.js';
import 'node:http';
import 'discord.js';
import './logger.js';

/**
 * Returns the currently loaded configuration.
 * May return null if config has yet to load. Use {@link loadConfig} to load it first.
 */
declare function getConfig(): Config | null;
/**
 * Returns the paths to all loaded configuration files.
 */
declare function getConfigPaths(): Set<string>;
declare function loadConfig(file?: string): Promise<Config>;
/**
 * Looks for the config file in the current project.
 * Will look for the following files in order:
 * - config/robo.mjs
 * - config/robo.cjs
 * - config/robo.json
 * - .config/robo.mjs
 * - .config/robo.cjs
 * - .config/robo.json
 *
 * @param file The name of the config file to look for. Defaults to "robo".
 * @returns The path to the config file, or null if it could not be found.
 */
declare function loadConfigPath(file?: string): Promise<string>;

export { getConfig, getConfigPaths, loadConfig, loadConfigPath };
